[![GitHub Actions Workflow Status](https://img.shields.io/github/actions/workflow/status/nickelpro/velocem/main.yaml?style=for-the-badge)](https://github.com/nickelpro/velocem/actions/workflows/main.yaml)
[![Gunicorn](https://img.shields.io/badge/Faster%20Than%20Gunicorn-1418%25-08824c?style=for-the-badge)](https://github.com/benoitc/gunicorn)
[![FastWSGI](https://img.shields.io/badge/Faster%20Than%20FastWSGI-4.68%25-lightblue?style=for-the-badge)](https://github.com/jamesroberts/fastwsgi)

# Velocem

This is a Work-In-Progress experimental Python extension. It aims to provide
a stupid-fast, pointlessly low-latency, web development framework.

If you use this code in production you get what you deserve.

## License

The Velocem source code (and associated build/test/utility files) is released
into the public domain via CC0-1.0, see `License` for details.

I (Vito Gamberini) hold no patents and have no knowledge of any patented
techniques used by Velocem. However, some organizations refuse to incorporate or
distribute public domain code due to patent concerns, for this reason Velocem is
additionally licensed for use under MIT-0, see `UsageLicense` for details.

The purpose in using these well known legal texts is that they are widely
trusted and understood by the open source community. A bespoke legal text might
limit usage by particularly skittish developers or organizations. However, I
want to make my intentions clear in plain English as well:

**Do what you want with this stuff. There are zero restrictions on the use of
this code in any context.**
